==> bouml_2.26.3.orig.tar.gz: bouml_2.26.3/src/RoundtripBody/UmlPackage.h <==
// *************************************************************************
//
// Copyleft 2004-2007 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLPACKAGE_H
#define UMLPACKAGE_H

#include "UmlBasePackage.h"

struct Dir {
  QCString src;
  QCString h;
  bool read;
};
 
class UmlPackage : public UmlBasePackage {
  public:
    UmlPackage(void * id, const QCString & n);
  
  protected:
    Dir dir;
  
  public:
    QCString source_path(const QCString &);
    QCString header_path(const QCString &);
    QCString java_path(const QCString &);
    virtual void roundtrip_cpp();
    virtual void roundtrip_java();
    virtual UmlPackage * package();
    
    static QCString rootDir(bool cpp);
};

#endif

==> bouml_3.3.4.orig.tar.gz: bouml_3.3.4/src/RoundtripBody/UmlPackage.h <==
// *************************************************************************
//
// Copyleft 2004-2007 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLPACKAGE_H
#define UMLPACKAGE_H

#include "UmlBasePackage.h"
#include "aLanguage.h"

struct Dir {
  QCString src;
  QCString h;
  bool read;
};
 
class UmlPackage : public UmlBasePackage {
  public:
    UmlPackage(void * id, const QCString & n);
  
  protected:
    Dir dir;
  
  public:
    QCString source_path(const QCString &);
    QCString header_path(const QCString &);
    QCString java_path(const QCString &);
    QCString php_path(const QCString &);
    virtual void roundtrip_cpp();
    virtual void roundtrip_java();
    virtual void roundtrip_php();
    virtual UmlPackage * package();
    
    static QCString rootDir(aLanguage who);
};

#endif
